#
# spec file for package libetonyek
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libetonyek-0_1-1
Name:           libetonyek
Version:        0.1.6
Release:        6.3
Summary:        Library for Apple Keynote presentations
License:        MPL-2.0
Group:          Productivity/Publishing/Word
Url:            https://wiki.documentfoundation.org/DLP/Libraries/libetonyek
Source0:        http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
Patch0:         libetonyek-0.1.6-drop_test.patch
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glm-devel
BuildRequires:  gperf
BuildRequires:  help2man
BuildRequires:  liblangtag-devel
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-generators-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mdds-1.0)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libetonyek is library providing ability to interpret and import Apple Keynote
presentations into various applications.

%package -n %{libname}
Summary:        Library for parsing the Apple Keynote presentations
Group:          System/Libraries

%description -n %{libname}
Libetonyek is library providing ability to interpret and import Apple Keynote
presentations into various applications.

%package devel
Summary:        Files for Developing with libetonyek
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libwpd-devel

%description devel
Libetonyek is library providing ability to interpret and import Apple Keynote
presentations into various applications.

This package contains the libetonyek development files.

%package devel-doc
Summary:        Documentation for the libetonyek API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libetonyek API.

%package tools
Summary:        Tools to work with Apple Keynote presentations
Group:          Productivity/Publishing/Word

%description tools
This package contains tools to work with Apple Keynote presentations

%prep
%setup -q
%patch0 -p1

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}-devel/html
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

find %{buildroot} -type f -name "*.la" -delete -print

mkdir -p %{buildroot}%{_mandir}/man1
for i in %{buildroot}%{_bindir}/*; do
  LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
  help2man -N -o %{buildroot}%{_mandir}/man1/$(basename $i).1 $i
done

cp -p AUTHORS COPYING ChangeLog %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}

%check
make check %{?_smp_mflags}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}-devel/
%doc %{_docdir}/%{name}-devel/[A-Z]*
%{_libdir}/*.so
%{_libdir}/pkgconfig/lib*.pc
%{_includedir}/%{name}-*

%files devel-doc
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-devel/html/

%files tools
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%{_bindir}/*
%{_mandir}/man1/*.1*

%changelog
* Fri Sep 30 2016 fstrba@suse.com
- Added patch:
  * libetonyek-0.1.6-drop_test.patch bnc#1015467
  - Drop test that violates Unicode tr#35 and thus fails with
    recent liblangtag
* Wed Jan 13 2016 fstrba@suse.com
- Version bump to 0.1.6:
  * All formats:
    + Improved handling of text language, e.g., written language
    props now include country and script.
  * Keynote 6:
    + Parse links.
    + Parse text language.
    + Parse lists (bullets).
    + Resize tables properly.
    + Fix handling of texts containing non-ASCII characters (i.e.,
    the majority of non-English languages).
  * Miscellaneous:
    + Fix build with boost 1.54/1.55.
    + Make help output of conversion tools more help2man-friendly.
    + Fix build with recent clang, which does not like 'register'
    keyword.
    + Various small fixes and improvements.
  * Changes to 0.1.5
    + Parse slide background.
    + Parse shape style: fill, line stroke, opacity, shadow.
    + Parse table style: default cell borders, background etc.
    + Various fixes and improvements.
  * Changes to 0.1.4
  * Parse formulas.
  * Parse cell type and number format.
  * Require mdds 1.0 by default (but 0.12.1 is still supported).
  * Add support for Keynote 6. Imported features include: shapes,
    images, text + text formatting, presentation notes, tables
    (only simple tables are supported.)
- Generate manpages for the conversion tools
* Wed Jun 24 2015 tchvatal@suse.com
- Version bump to 0.1.3:
  * Various small fixes
  * More imported now imported
  * Now use mdds to help with some hashing
- Remove included patch:
  * 0001-fix-test-on-i386.patch
* Mon Jun 15 2015 tchvatal@suse.com
- Add patch to fix testsuite on i586:
  * 0001-fix-test-on-i386.patch
* Sat Jun 13 2015 tchvatal@suse.com
- Version bump to 0.1.2:
  * Initial support for pages and numbers
  * Ditch libetonyek-0.1.1-constants.patch as we do not require
    us to build for older boost
* Fri Jul 11 2014 tchvatal@suse.com
- Update Source URL to have auto-download working again.
* Wed Jul  2 2014 fstrba@suse.com
- libetonyek-0.1.1-constants.patch
  * Ditch the boost/math/constants/constants.hpp altogether
  * Fixes build on systems with older boost
* Tue Jun  3 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.1
  * Fix detection of Keynote 3 documents.
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI change
  * Remove dependency on libwpd-devel
  * Add dependency on librevenge-devel
* Tue May 20 2014 tchvatal@suse.com
- Version bump to 0.0.4:
  * Various bugfixes found during the libreoffice-4.2 cycle
- Drop upstreamed patches:
  * libetonyek-0.0.3-comma.patch
  * libetonyek-0.0.3-lexical_cast.patch
  * libetonyek-more-lib64.patch
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden, around 400 symbols
  less in the export symbol table.
* Mon Jan  6 2014 matz@suse.com
- Add ppc64le to list of lib64 archs for boost detection
  Added patches:
  * libetonyek-more-lib64.patch
* Fri Dec 27 2013 tchvatal@suse.com
- Drop useless dep over libwpg. Cleanup whitespace.
* Sun Dec 15 2013 fridrich.strba@bluewin.ch
- Fix build with some boost versions and compilers
  - Cannot take address of a template function
- added patches:
  * libetonyek-0.0.3-lexical_cast.patch
* Sun Dec 15 2013 fridrich.strba@bluewin.ch
- Fix comma at the end of an enum.
- added patches:
  * libetonyek-0.0.3-comma.patch
* Sat Dec 14 2013 fridrich.strba@bluewin.ch
- Bump to 0.0.3
  - import text formatting attributes
  - draw rounded rectangles and callouts
  - fixed build with older boost
  - implemented import of tables
  - implemented import of presentation notes
  - implemented import of sticky notes
- removed patches:
  * libetonyek-0.0.0-pi.patch - integrated upstream
* Tue Nov 12 2013 fstrba@suse.com
- Modify libetonyek-0.0.0-pi.patch
  * fixes build of tests with less recent boost versions
* Sat Nov  9 2013 tchvatal@suse.com
- Bump to 0.0.1
  * Fixes test
  * Various runtime fixes
* Fri Nov  8 2013 fridrich.strba@suse.com
- Add libetonyek-0.0.0-pi.patch
  * fixes build problems with less recent boost versions
- Don't build noarch docs for SLE11
* Fri Nov  1 2013 tchvatal@suse.com
- Make the package actually build.
* Fri Nov  1 2013 tchvatal@suse.com
- Initial commit, needed by libreo-4.2
